summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-03-20 08:50:30 -0400
committerGregory Wlodarek <gregory.wlodarek@mongodb.com>2019-03-20 12:52:21 -0400
commiteb5136ad33e9821580843be0ac7b981a16cc30c5 (patch)
treec726a19e1ed9c6515df021ab7c50c00817ff4e44
parent79a301a6fdf621019259a01f95ddbe9a1ebd8205 (diff)
downloadmongo-eb5136ad33e9821580843be0ac7b981a16cc30c5.tar.gz
SERVER-40233 Increase transactionLifetimeLimitSeconds from 3 to 24 hours
-rw-r--r--buildscripts/resmokelib/core/programs.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/buildscripts/resmokelib/core/programs.py b/buildscripts/resmokelib/core/programs.py
index a3e9dd60241..956f4625b84 100644
--- a/buildscripts/resmokelib/core/programs.py
+++ b/buildscripts/resmokelib/core/programs.py
@@ -82,10 +82,10 @@ def mongod_program( # pylint: disable=too-many-branches
# There's a periodic background thread that checks for and aborts expired transactions.
# "transactionLifetimeLimitSeconds" specifies for how long a transaction can run before expiring
# and being aborted by the background thread. It defaults to 60 seconds, which is too short to
# be reliable for our tests. Setting it to 3 hours, so that it is longer than the 2 hours we
# allow JS tests to run before timing them out.
if "transactionLifetimeLimitSeconds" not in suite_set_parameters:
- suite_set_parameters["transactionLifetimeLimitSeconds"] = 3 * 60 * 60
+ suite_set_parameters["transactionLifetimeLimitSeconds"] = 24 * 60 * 60
# The periodic no-op writer writes an oplog entry of type='n' once every 10 seconds. This has
# the potential to mask issues such as SERVER-31609 because it allows the operationTime of
@@ -248,10 +248,10 @@ def mongo_shell_program( # pylint: disable=too-many-branches,too-many-locals,to
# There's a periodic background thread that checks for and aborts expired transactions.
# "transactionLifetimeLimitSeconds" specifies for how long a transaction can run before expiring
# and being aborted by the background thread. It defaults to 60 seconds, which is too short to
# be reliable for our tests. Setting it to 3 hours, so that it is longer than the 2 hours we
# allow JS tests to run before timing them out.
if "transactionLifetimeLimitSeconds" not in test_data:
- test_data["transactionLifetimeLimitSeconds"] = 3 * 60 * 60
+ test_data["transactionLifetimeLimitSeconds"] = 24 * 60 * 60
if "eval_prepend" in kwargs:
eval_sb.append(str(kwargs.pop("eval_prepend")))
@@ -82,10 +82,10 @@ def mongod_program( # pylint: disable=too-many-branches
# "transactionLifetimeLimitSeconds" specifies for how long a transaction can run before expiring
# and being aborted by the background thread. It defaults to 60 seconds, which is too short to
- # be reliable for our tests. Setting it to 3 hours, so that it is longer than the 2 hours we
- # allow JS tests to run before timing them out.
+ # be reliable for our tests. Setting it to 24 hours, so that it is longer than the Evergreen
+ # execution timeout.
if "transactionLifetimeLimitSeconds" not in suite_set_parameters:
@@ -248,10 +248,10 @@ def mongo_shell_program( # pylint: disable=too-many-branches,too-many-locals,to
# "transactionLifetimeLimitSeconds" specifies for how long a transaction can run before expiring
# and being aborted by the background thread. It defaults to 60 seconds, which is too short to
- # be reliable for our tests. Setting it to 3 hours, so that it is longer than the 2 hours we
- # allow JS tests to run before timing them out.
+ # be reliable for our tests. Setting it to 24 hours, so that it is longer than the Evergreen
+ # execution timeout.
if "transactionLifetimeLimitSeconds" not in test_data: